Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: gm/multipicturedraw.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gm/morphology.cpp ('k') | gm/ninepatchstretch.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gm/multipicturedraw.cpp
diff --git a/gm/multipicturedraw.cpp b/gm/multipicturedraw.cpp
index 3a0b0fa7d9e02578280d1c11b6775fbba85188a7..88d6cd798f931ab0bdb0fbc9f5656f182bc9d37c 100644
--- a/gm/multipicturedraw.cpp
+++ b/gm/multipicturedraw.cpp
@@ -68,7 +68,7 @@ static const SkPicture* make_hex_plane_picture(SkColor fillColor) {
xPos = 0;
for (int x = 0; x < kNumHexX; ++x) {
- canvas->saveLayer(NULL, NULL);
+ canvas->saveLayer(nullptr, nullptr);
canvas->translate(xPos, yPos + ((x % 2) ? kRoot3Over2 * kHexSide : 0));
canvas->drawPath(hex, fill);
canvas->drawPath(hex, stroke);
@@ -111,7 +111,7 @@ static const SkPicture* make_single_layer_hex_plane_picture() {
SkCanvas* canvas = recorder.beginRecording(kBig, kBig, &bbhFactory,
SkPictureRecorder::kComputeSaveLayerInfo_RecordFlag);
- canvas->saveLayer(NULL, NULL);
+ canvas->saveLayer(nullptr, nullptr);
SkScalar xPos = 0.0f, yPos = 0.0f;
@@ -171,7 +171,7 @@ static const SkPicture* make_tri_picture() {
r.outset(2.0f, 2.0f); // outset for stroke
canvas->clipRect(r);
// The saveLayer/restore block is to exercise layer hoisting
- canvas->saveLayer(NULL, NULL);
+ canvas->saveLayer(nullptr, nullptr);
canvas->drawPath(tri, fill);
canvas->drawPath(tri, stroke);
canvas->restore();
@@ -245,8 +245,8 @@ static SkSurface* create_compat_surface(SkCanvas* canvas, int width, int height)
SkImageInfo info = SkImageInfo::MakeN32Premul(width, height);
SkSurface* surface = canvas->newSurface(info);
- if (NULL == surface) {
- // picture canvas returns NULL so fall back to raster
+ if (nullptr == surface) {
+ // picture canvas returns nullptr so fall back to raster
surface = SkSurface::NewRaster(info);
}
@@ -257,7 +257,7 @@ static SkSurface* create_compat_surface(SkCanvas* canvas, int width, int height)
// fragments potentially generated by the MultiPictureDraw object
class ComposeStep {
public:
- ComposeStep() : fSurf(NULL), fX(0.0f), fY(0.0f), fPaint(NULL) { }
+ ComposeStep() : fSurf(nullptr), fX(0.0f), fY(0.0f), fPaint(nullptr) { }
~ComposeStep() {
SkSafeUnref(fSurf);
delete fPaint;
@@ -474,7 +474,7 @@ namespace skiagm {
SkASSERT(SK_ARRAY_COUNT(gContentMthds) == kContentCnt);
for (int i = 0; i < kNumPictures; ++i) {
- fPictures[i] = NULL;
+ fPictures[i] = nullptr;
}
}
« no previous file with comments | « gm/morphology.cpp ('k') | gm/ninepatchstretch.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698